#!/bin/sh

if [ -n "$CC" ]; then
    cc=`basename "$CC"`
else
    cc=gcc
fi

os=`uname -s | awk '{ print $1 }' | tr a-z A-Z`

case "$os" in

LINUX)
    rev=`uname -r`
    osmajor=`echo $rev | awk -F. '{ printf "%d%d", $1, $2 }'`
    osminor=`echo $rev | awk -F. '{ printf "%d", $3 }'`

    if [ -z "$int64format" ]; then
	int64format='ll'
    fi
    cflags="-DNEED_XDR_INT64 -DHAVE_MALLOC_H"
    lflags=

    if [ -z "$READLINE_DIR" ]; then
	READLINE_DIR=/usr
	export READLINE_DIR
    fi
    ;;

SUNOS)
    rev=`uname -r`
    osmajor=`echo $rev | awk -F. '{ printf "%d%d", $1, $2 }'`
    osminor=`echo $rev | awk -F. '{ printf "%d", $3 }'`

    if [ -z "$int64format" ]; then
	int64format='ll'
    fi
    cflags="-DBYTE_ORDER=__BYTE_ORDER__ -DHAVE_MALLOC_H -DHAVE_CLNT_SOC_H"
    lflags="-lrpcsvc -lsocket -lnsl -ltermlib"
    ;;

IRIX)
    rev=`uname -R | sed -e 's/^[0-9\.]* //' -e 's/[fm]$//'`
    osmajor=`echo $rev | awk -F. '{ printf "%d%d", $1, $2 }'`
    osminor=`echo $rev | awk -F. '{ printf "%d", $3 }'`

    if [ -z "$int64format" ]; then
	int64format='ll'
    fi
    cflags="-DHAVE_MALLOC_H -DHAVE_CLNT_SOC_H"
    if [ "$cc" = cc ]; then
	cflags="$cflags -n32 -mips3"
	lflags="$lflags -n32 -mips3"
    fi
    lflags=
    ;;

FREEBSD)
    rev=`uname -r | sed -e 's/\-.*$//'`
    osmajor=`echo $rev | awk -F. '{ printf "%d%d", $1, $2 }'`
    osminor=`echo $rev | awk -F. '{ printf "%d", $3 }'`

    if [ -z "$int64format" ]; then
	int64format='ll'
    fi
    cflags="-DNEED_XDR_INT64 -DHAVE_ENDIAN_H"
    lflags=

    if [ -z "$READLINE_DIR" ]; then
	READLINE_DIR=/usr
	export READLINE_DIR
    fi
    ;;

*)
    echo 'Unknown OS type. See osdefs.sh.' >&2
    echo "exit 1"
    exit 1

esac

cflags="$cflags -DPRINTF_INT64_FORMAT='\\\"$int64format\\\"'"

if [ -n "$READLINE_DIR" ]; then
    cflags="$cflags -DUSE_READLINE -I. -I$READLINE_DIR/include"
    lflags="-L$READLINE_DIR/lib -lreadline -lcurses $lflags"
    if [ $os = SUNOS -a $osmajor -ge 56 ]; then
	lflags="$lflags -ltermcap"
    fi
fi

if [ $cc = "gcc" ]; then
    cflags="-DGCC -g -Wall $cflags"
    lflags="-g $lflags"
else
    cflags="-g $cflags"
    lflags="-g $lflags"
fi

echo CC=$cc
echo CFLAGS=\"-D$os -DOSMAJOR=$osmajor -DOSMINOR=$osminor $cflags $CFLAGS\"
echo LFLAGS=\"$lflags $LFLAGS\"
echo export CC CFLAGS LFLAGS

